#
# spec file for package perl-Test-Base
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Test-Base
Version:        0.89
Release:        1.25
%define cpan_name Test-Base
Summary:        Data Driven Testing Framework
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Test-Base/
Source0:        https://cpan.metacpan.org/authors/id/I/IN/INGY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Algorithm::Diff) >= 1.15
BuildRequires:  perl(Spiffy) >= 0.40
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Text::Diff) >= 0.35
Requires:       perl(Spiffy) >= 0.40
Requires:       perl(Test::More) >= 0.88
Recommends:     perl(Test::Deep)
%{perl_requires}

%description
Testing is usually the ugly part of Perl module authoring. Perl gives you a
standard way to run tests with Test::Harness, and basic testing primitives
with Test::More. After that you are pretty much on your own to develop a
testing framework and philosophy. Test::More encourages you to make your
own framework by subclassing Test::Builder, but that is not trivial.

Test::Base gives you a way to write your own test framework base class that
_is_ trivial. In fact it is as simple as two lines:

    package MyTestFramework;
    use Test::Base -Base;

A module called 'MyTestFramework.pm' containing those two lines, will give
all the power of Test::More and all the power of Test::Base to every test
file that uses it. As you build up the capabilities of 'MyTestFramework',
your tests will have all of that power as well.

'MyTestFramework' becomes a place for you to put all of your reusable
testing bits. As you write tests, you will see patterns and duplication,
and you can "upstream" them into 'MyTestFramework'. Of course, you don't
have to subclass Test::Base at all. You can use it directly in many
applications, including everywhere you would use Test::More.

Test::Base concentrates on offering reusable data driven patterns, so that
you can write tests with a minimum of code. At the heart of all testing you
have inputs, processes and expected outputs. Test::Base provides some clean
ways for you to express your input and expected output data, so you can
spend your

      time focusing on that rather than your code scaffolding.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Fri Apr 20 2018 coolo@suse.com
- updated to 0.89
  see /usr/share/doc/packages/perl-Test-Base/Changes
  0.89 Thu Apr 19 08:54:04 PDT 2018
  - Apply PR/19 and PR/21 from @perlpunk++
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.88
  - Remove a debugging line.
  0.87 Tue Aug 19 16:35:34 PDT 2014
  - Replace tabs with spaces
  0.86 Mon Aug 18 08:29:20 PDT 2014
  - Fix for issue/15
  0.85 Mon Aug 18 08:07:52 PDT 2014
  - Pull Module::Install::TestBase out of Test::Base
  - It will be released in separate dist
  - Was causing Test::Base to fail tests
  0.84 Sat Aug 16 15:08:32 PDT 2014
  - Remove .gitignore
  - Fix Meta error. s/zild/=zild/
  0.83 Sat Aug 16 12:31:00 PDT 2014
  - Meta 0.0.2
  0.82 Sat Aug 16 04:14:25 PDT 2014
  - Eliminate spurious trailing whitespace
  0.81 Sat Aug 16 02:52:12 PDT 2014
  - Eliminate File::Basename from test/
  0.80 Fri Aug 15 20:49:55 PDT 2014
  - Add t/000-require-modules.t
  0.79 Sat Aug  9 00:55:07 PDT 2014
  - Dep on EU::MM 6.52
* Wed Apr  6 2011 coolo@novell.com
- updated to 0.60
  - Applied patch by andk++
  - Make regexp test skip on 5.14 for now.
* Wed Mar 16 2011 cfarrell@novell.com
- license update: GPL+ or Artistic
  Same license as perl expands to GPL+ or Artistic under current rpm spec file license syntax
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Mar  8 2010 ro@suse.de
- try BuildIgnore to fix buildreq cycle
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sun Dec 13 2009 chris@computersalat.de
- update to 0.59
  - Fixed test dep bug reported by Alias++
- removed useless patch
- update desc
- fixed build-/deps
  o added Algorithm::Diff, Text::Diff
  o fix Spiffy >= 0.30
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 20 2009 chris@computersalat.de
- update to 0.58
  o Another undef filtering change.
- version: 0.57
  o Allow value of undef to be filtered without warnings.
- version: 0.56
  o Add Test::Deep support with is_deep and run_is_deep
- version: 0.55
  o Module::Install::TestBase::use_test_base require 'Filter::Util::Call' now.
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
- added req patch
  o needs Test/Deep
* Tue Jul 24 2007 cwh@suse.de
- version 0.54: Make dependency on Filter::Util::Call explicit in Makefile.PL
- version 0.53: Changes from miyagawa and crew
* Wed Oct 25 2006 cwh@suse.de
- version: 0.52
  - Add use_ok to exports
- version: 0.51
  - Remove build-requires dep of Spiffy for Module::Install::TestBase
  - Add in a patch from the good folk at Socialtext.
- version: 0.50
  - No change. 0.49 got borked on the way to CPAN
- version: 0.49
  - Added Module::Install::TestBase
- version: 0.48
  - Fixed test failures on windows
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 cwh@suse.de
- Initially packaged for SUSE Linux
